// Function to handle active class updates on intersection
const changeNav = (entries, observer) => {
	entries.forEach((entry) => {
		// Verify the element is intersecting
		if (entry.isIntersecting && entry.intersectionRatio >= 0.55) {
			// Get ID of the intersecting section
			const sectionId = entry.target.getAttribute('id');

			// Skip if the section has no ID
			if (!sectionId) return;

			// Find the matching nav link by data-active attribute
			const newLink = document.querySelector(`div.mw_Inline_Section_Nav > nav a[data-active="${sectionId}"]`);

			// Only proceed if a matching link is found
			if (newLink) {
				// Forcefully remove active class from all nav links
				document.querySelectorAll('div.mw_Inline_Section_Nav > nav a').forEach((link) => {
					// console.log(link);
					link.classList.remove('active');
				});


				// Add active class to the new link
				newLink.classList.add('active');
				// console.log(newLink);
			}
		}
	});
};

// Function to handle active class on nav link clicks
const handleNavClick = (event) => {
	// Remove the active class from all nav links
	const navLinks = document.querySelectorAll('div.mw_Inline_Section_Nav > nav a');
	navLinks.forEach((link) => link.classList.remove('active'));

	// Add the active class to the clicked link
	event.target.classList.add('active');
};

// Initialize the observer
const options = {
	threshold: 0.55
};

const observer = new IntersectionObserver(changeNav, options);

// Target the `.et_pb_section` elements to be observed
const sections = document.querySelectorAll('div.et_pb_section');
sections.forEach((section) => {
	observer.observe(section);
});

// Add click event listeners to the nav links
const navLinks = document.querySelectorAll('div.mw_Inline_Section_Nav > nav a');
navLinks.forEach((link) => {
	link.addEventListener('click', handleNavClick);
});