<?php
class MW_Inline_Section_Nav_Module extends ET_Builder_Module 
{
	function init()
	{
		$this->name            = 'Inline Section Nav';
		$this->slug            = 'mw_Inline_Section_Nav';
		$this->version         = '1.0.0';
		$this->child_slug = 'Inline_Section_Nav_item';
		$this->child_item_text = et_builder_i18n( 'name' );
		$this->main_css_element = '%%order_class%%';
	}
	
	public function get_advanced_fields_config(){
		$advanced_fields = [];
		$advanced_fields['animation'] = FALSE;
		$advanced_fields['background'] = [];
		$advanced_fields['fonts']['nav_link'] = [
			'label' => "Nav Links",
			'css' => [
				'main' => "{$this->main_css_element} nav li a",
			],
			'line_height' => [
				'default' => '2em',
			],
		];
		$advanced_fields['fonts']['nav_link_active'] = [
			'label' => "Nav Links:Active",
			'css' => [
				'main' => "{$this->main_css_element} nav li a.active ",
			],
			'line_height' => [
				'default' => '2em',
			],
		];
		return $advanced_fields;
	}

	function get_fields()
	{
		return [
			'rounding' => [
				'label' => 'Nav Rounding',
				'type' => 'select',
				'options'          => array(
					'rounded'  => esc_html__( 'Rounded', 'et_builder' ),
					'roundish'   => esc_html__( 'Slight Rounding', 'et_builder' ),
					'square'  => esc_html__( 'Square', 'et_builder' ),
				),
				'default'          => 'rounded',
				'description' => '',
			],
			'active_bg'     => array(
				'label'          => 'Active Background Colour',
				'description'    => 'Pick a color to go behinde the active item.',
				'type'           => 'color-alpha',
				'custom_color'   => true,
			),
		];
	}

	public function render($atts, $content, $render_slug)
	{
		$rounding = $this->props['rounding'];
		$active_bg = $this->props['active_bg'];
		$output = sprintf(
			'<div %1$s class="%2$s et_pb_module %3$s" >
			<nav class="%4$s">
				<ul>
					%3$s
				</ul>
			</div>',
			$this->module_id(),
			$this->module_classname( $render_slug ),
			et_core_sanitized_previously($this->content),
			$rounding
		);
		
		
		if($active_bg != ''){
			$background = "background-color: $active_bg !important;";
			ET_Builder_Element::set_style(
				$function_name,
				array(
					'selector'    => "nav a.active",
					'declaration' => $background,
				)
			);
		}
		
		$current_directory_url = trailingslashit( wp_make_link_relative( get_template_directory_uri() . str_replace( get_template_directory(), '', __DIR__ ) ) );

		wp_enqueue_style('Inline_Section_Nav', $current_directory_url.'/assets/Inline_Section_Nav.css', [], $this->version);
		wp_enqueue_script('Inline_Section_Nav', $current_directory_url.'/assets/Inline_Section_Nav.js', [], $this->version);
		return do_shortcode($output);
	}
}

new MW_Inline_Section_Nav_Module();
