<?php

class Inline_Section_Nav_item extends ET_Builder_Module
{

	public function init()
	{
		$this->slug = 'Inline_Section_Nav_item';
		$this->type = 'child';
		$this->name = esc_html__('Nav Item', 'dipi-divi-pixel');
		$this->main_css_element = '%%order_class%%.dipi_button_grid_child';
		$this->child_title_var = 'text';
		$this->advanced_setting_title_text = 'New Item';
		$this->settings_text = 'Item Settings';
	}

	public function get_settings_modal_toggles()
	{
		return [
			'general' => [
				'toggles' => [
					'general' => esc_html__('General', 'dipi-divi-pixel'),
					'button_info' => esc_html__('Button Settings', 'dipi-divi-pixel'),
					'text_info' => esc_html__('Text Settings', 'dipi-divi-pixel'),
				],
			],
			'advanced' => [
				'toggles' => [
					'text_style' => esc_html__('Text Style', 'dipi-divi-pixel')
				]
			],
			'custom_css' => [
				'toggles' => [
					'classes' => esc_html__('CSS ID & Classes', 'dipi-divi-pixel'),
				],
			]
		];
	}

	public function get_custom_css_fields_config()
	{
		$fields = [];

		$fields['button_type'] = array(
			'label' => esc_html__('Button Style', 'dipi-divi-pixel'),
			'selector' => '%%order_class%% .button-wrap',
		);

		$fields['text_type'] = array(
			'label' => esc_html__('Text Style', 'dipi-divi-pixel'),
			'selector' => '%%order_class%% .text-wrap',
		);

		return $fields;
	}

	public function get_fields()
	{
		$fields = [];

		$fields["text"] = [
			'label' => 'Nav Item Text', 
			'type' => 'text',
			'option_category' => 'basic_option',
			'toggle_slug' => 'general',
			'description'  => 'The text in the achor tag.',
		];

		$fields["target"] = [
			'label' => 'Nav Item Target', 
			'type' => 'text',
			'option_category' => 'basic_option',
			'toggle_slug' => 'general',
			'description'  => 'URL or Hash link that this item so=hould link to.',
		];

		$fields['active_id'] = [
			'label' => 'Active Section ID',
			'type' => 'text',
			'option_category' => 'basic_option',
			'toggle_slug' => 'general',
			'description'  => 'The DIVI section thet when in view will make this item active.',
		];

		return $fields;
	}

	public function get_advanced_fields_config()
	{
		$advanced_fields = [];
		$advanced_fields["text"] = false;
		$advanced_fields["text_shadow"] = false;
		$advanced_fields["link_options"] = false;

		$advanced_fields['margin_padding'] = [
			'css' => [
				'margin' => '%%order_class%%',
				'padding' => '%%order_class%%',
				'important' => 'all',
			],
		];

		$advanced_fields['fonts']['text_style'] = [
			'css' => [
				'main' => "%%order_class%% .text-wrap",
				'important' => 'all',
			],
			'text_align' => [
				'default' => 'center',
			],
			'font_size' => [
				'default' => '16px',
				'range_settings' => [
					'min' => '1',
					'max' => '50',
					'step' => '1',
				],
			],
			'line_height' => [
				'default' => '1em',
				'range_settings' => [
					'min' => '1',
					'max' => '3',
					'step' => '0.1',
				],
			],
			'toggle_slug' => 'text_style',
		];

		$advanced_fields['button']["button"] = [
			'label'    => esc_html__('Button Style', 'dipi-divi-pixel'),
			'css' => [
				'main' => "%%order_class%% .button-wrap",
				'limited_main' => "%%order_class%% .button-wrap",
				'important' => true,
			],
			'box_shadow'  => [
				'css' => [
					'main' => "%%order_class%% .button-wrap",
					'important' => true,
				],
			],
			'use_alignment' => false,
			'margin_padding' => [
				'css' => [
					'main' => "%%order_class%% .button-wrap",
					'important' => 'all',
				],
			]

		];

		return $advanced_fields;
	}
	
	public function custom_shortcode_processor($content) {
		$content = str_replace('&#91;', '[', $content);
		$content = str_replace('&#93;', ']', $content);
		$content = str_replace('%91', '[', $content);
		$content = str_replace('%93', ']', $content);
			$content = do_shortcode($content); // Execute shortcodes
		$content = str_replace('[', '&#91;', $content);
		$content = str_replace(']', '&#93;', $content);   
		return $content;
	}


	public function render($attrs, $content, $render_slug)
	{
		$target = $this->props['target'];
		$active_id = $this->props['active_id'];
		$text = $this->props['text'];
		
		$item_output = "<li><a href='$target' data-active='$active_id'>$text</a></li>";


		return $item_output;
	}
}

new Inline_Section_Nav_item();
